from .alacritty import Alacritty
from .bash import Bash
from .gimp import Gimp
from .lf import Lf
from .mpv import Mpv
from .neovim import Neovim
from .qutebrowser import Qutebrowser
from .rofi import Rofi
from .sioyek import Sioyek
from .sxhkd import Sxhkd
from .sxiv import Sxiv
from .termite import Termite
from .vim import Vim
from .vimiv import Vimiv
from .zathura import Zathura
from .zsh import Zsh

__all__ = [
    "Alacritty",
    "Bash",
    "Gimp",
    "Lf",
    "Mpv",
    "Neovim",
    "Qutebrowser",
    "Rofi",
    "Sioyek",
    "Sxhkd",
    "Sxiv",
    "Termite",
    "Vim",
    "Vimiv",
    "Zathura",
    "Zsh",
]
